@@ -18,14 +18,11 @@ from django.utils.translation import ugettext_lazy as _
 from sentry.web.helpers import render_to_string
 
 
-# unserialization concept is based on pickle
-class _EmptyClass(object):
-    pass
+_Exception = Exception
 
 
 def unserialize(klass, data):
-    value = _EmptyClass()
-    value.__class__ = klass
+    value = object.__new__(klass)
     value.__setstate__(data)
     return value
 
@@ -372,7 +369,7 @@ class Http(Interface):
         if self.headers.get('Content-Type') == 'application/x-www-form-urlencoded':
             try:
                 data = QueryDict(data)
-            except Exception:
+            except _Exception:
                 pass
             else:
                 data_is_dict = True
@@ -383,7 +380,7 @@ class Http(Interface):
         if not cookies_is_dict:
             try:
                 cookies = QueryDict(cookies)
-            except Exception:
+            except _Exception:
                 pass
             else:
                 cookies_is_dict = True
